@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,12 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcloudauth.endpoint import endpoint_data
+
 class DetectFaceAttributesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cloudauth', '2018-09-16', 'DetectFaceAttributes','cloudauth')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_MaxNumPhotosPerCategory(self):
 		return self.get_body_params().get('MaxNumPhotosPerCategory')
@@ -43,18 +50,24 @@ class DetectFaceAttributesRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
-	def get_SourceIp(self):
-		return self.get_query_params().get('SourceIp')
-
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
 	def get_RetAttributes(self):
 		return self.get_body_params().get('RetAttributes')
 
 	def set_RetAttributes(self,RetAttributes):
 		self.add_body_params('RetAttributes', RetAttributes)
 
+	def get_ClientTag(self):
+		return self.get_body_params().get('ClientTag')
+
+	def set_ClientTag(self,ClientTag):
+		self.add_body_params('ClientTag', ClientTag)
+
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
+
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
+
 	def get_MaterialValue(self):
 		return self.get_body_params().get('MaterialValue')
 
@@ -65,10 +78,4 @@ class DetectFaceAttributesRequest(RpcRequest):
 		return self.get_body_params().get('DontSaveDB')
 
 	def set_DontSaveDB(self,DontSaveDB):
-		self.add_body_params('DontSaveDB', DontSaveDB)
-
-	def get_ClientTag(self):
-		return self.get_body_params().get('ClientTag')
-
-	def set_ClientTag(self,ClientTag):
-		self.add_body_params('ClientTag', ClientTag)
\ No newline at end of file
+		self.add_body_params('DontSaveDB', DontSaveDB)
\ No newline at end of file
